from Products.Archetypes.public import *
from Products.Archetypes.Marshall import RFC822Marshaller
from Products.CMFCore import CMFCorePermissions
from config import PROJECTNAME
from URLWidget import URLWidget


def modify_fti(fti):
    fti['allow_discussion'] = 'none'
    # hide unnecessary tabs (usability enhancement)
    for a in fti['actions']:
        if a['id'] in ('references',):
            a['visible'] = 0
    return fti

#note - I'm using underscore naming for fields, so that I can use 'spacify' in forms and
#       get phrases or sentences.

schema = BaseSchema +  Schema((
    TextField('body',
                index='TextIndexNG2|TextIndex',
                widget=RichWidget(description='main webpage text'),
                required=1,
                default_output_type='text/html',
                allowable_content_types=('text/plain',
                       'text/restructured',
                       'text/structured',
                       'text/html',
                       'application/msword'),
                ),
    StringField('website',
                index='FieldIndex:schema',
                description='website',
                widget=URLWidget(description='link to your website'),
                validator='isURL',
                ),
    ImageField('logo',
                default_output_type='image/jpeg',
                allowable_content_types=('image/*',),
                widget=ImageWidget(description='your logo, if you have one', macro_view='small_image'),
                ),
    ImageField('image',
                default_output_type='image/jpeg',
                allowable_content_types=('image/*',),
                widget=ImageWidget(description='upload a picture or image', macro_view='medium_image'),
                ),
    ),
    marshall=RFC822Marshaller(),
    )

class WebPage(BaseContent):
    """
Simple way to let users create a web page, which includes a logo, image, and a link.
    """

    schema = schema

    actions = ({
        'id': 'view',
        'name': 'View',
        'action': 'string:${object_url}/webpage_view',
        'permissions': (CMFCorePermissions.View,)
        },)
        
    content_icon = "webpage_icon.gif"


#	override DublinCore methods
#     def Description(self):
#         return self.getPlugin_description(mimetype='text/plain')
# 
#     def setDescription(self, val):
#         return self.setPlugin_description(val)

#	use DublinCore Description for plugin description
#     def getPlugin_description(self):
#         # the accessor for dublin core metadata is a bit inconsistent
#         # with Archetype
#         return self.Description()
# 
#     def setPlugin_description(self, val):
#         return self.setDescription(val)
        
registerType(WebPage, PROJECTNAME)
